# types-s3transfer

[![PyPI - types-s3transfer](https://img.shields.io/pypi/v/types-s3transfer.svg?color=blue&label=types-s3transfer)](https://pypi.org/project/types-s3transfer)
[![PyPI - s3transfer](https://img.shields.io/pypi/v/s3transfer.svg?color=blue&label=s3transfer)](https://pypi.org/project/s3transfer)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-s3transfer.svg?color=blue)](https://pypi.org/project/types-s3transfer)
[![PyPI - Downloads](https://static.pepy.tech/badge/types-s3transfer)](https://pypistats.org/packages/types-s3transfer)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations and code completion for [s3transfer](https://pypi.org/project/s3transfer/) package.
This package is a part of [mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder) project.

[![Publish botocore-stubs](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/botocore-stubs/actions/workflows/publish_on_update.yml)
[![Publish types-awscrt](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-awscrt/actions/workflows/publish_on_update.yml)
[![Publish types-s3transfer](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml/badge.svg)](https://github.com/youtype/types-s3transfer/actions/workflows/publish_on_update.yml)


- [types-s3transfer](#types-s3transfer)
  - [Installation](#installation)
  - [Usage](#usage)
  - [Versioning](#versioning)
  - [Support and contributing](#support-and-contributing)


## Installation

```bash
python -m pip install types-s3transfer
```

## Usage

Use [mypy](https://github.com/python/mypy) or [pyright](https://github.com/microsoft/pyright) for type checking.

## Versioning

`types-s3transfer` version is the same as related `s3transfer` version and follows
[Python Packaging version specifiers](https://packaging.python.org/en/latest/specifications/version-specifiers/).

## Support and contributing

Please reports any bugs or request new features in
[types-s3transfer](https://github.com/youtype/types-s3transfer/issues/) repository.
